@@ -2,7 +2,7 @@ package HTTPD::ADS;
 use strict;
 use warnings;
 use vars qw ($VERSION @ISA );
-$VERSION     = 0.7;
+$VERSION     = 0.8;
 use base qw/ Class::Constructor Class::Accessor /;
 use HTTPD::ADS::DBI;
 use HTTPD::ADS::Times;		#time-related subroutines
@@ -218,7 +218,7 @@ sub analyze401 {
   }
 
   $self->blacklist(
-		   ip=>$ip, first_event => $self->first_eventid,block_reason => 401 
+		   ip=>$ip, first_event => $self->first_eventid($ip),block_reason => 401 
 		  )
     if ($eventcount >= $self->IDSEventsThresholdLevel);
 }
@@ -241,7 +241,7 @@ sub analyze401 {
 sub first_eventid {
   my $self = shift @_;
   my $ip = shift @_;
-  my $event=HTTPD::ADS::Eventrecords->search_first_error_event( $ip, $self->pgtimewindow )[0];
+  my $event= HTTPD::ADS::Eventrecords->first_error_event( $ip, $self->pgtimewindow );
   my $eventid = $event->eventid;
   return $eventid;
 }
